@@ -516,7 +516,7 @@ class pdfCalendar():
                         raise
                     if drawing is None:
                         logging.warning("ressource file not found:%s"%(ressource))
-                        warn_fp = abspath(join(__file__,pardir,pardir,"rsc","Warning.svg"))
+                        warn_fp = abspath(join(__file__,pardir,pardir,pardir,pardir,"rsc","Warning.svg"))
                         drawing = svg2rlg(warn_fp) 
                     if not showContent:
                         content = " "
